@@ -12,7 +12,12 @@ THUMBNAIL_STORAGE_BACKEND = 'thumbnails.storage_backends.FilesystemStorageBacken
 THUMBNAIL_SCALE_UP = False
 THUMBNAIL_QUALITY = 90
 THUMBNAIL_COLORMODE = 'RGB'
+THUMBNAIL_FALLBACK_FORMAT = 'JPEG'
+THUMBNAIL_FORCE_FORMAT = None
 THUMBNAIL_ALTERNATIVE_RESOLUTIONS = [2]
 
+THUMBNAIL_FILTER_SIZE = '500'
+THUMBNAIL_FILTER_OPTIONS = {'size': '500'}
+
 THUMBNAIL_DUMMY = False
-THUMBNAIL_DUMMY_URL = 'http://puppies.lkng.me/{}x{}'
+THUMBNAIL_DUMMY_URL = 'http://puppies.lkng.me/{width}x{height}'
